"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = treeify;

var _ramda = require("ramda");

var _mapWithIndex = require("../mapWithIndex");

var _mapWithIndex2 = _interopRequireDefault(_mapWithIndex);

var _nestedApply = require("../nestedApply");

var _nestedApply2 = _interopRequireDefault(_nestedApply);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function treeify(folders) {
  return function treeifyCollection(collection) {
    return (0, _ramda.reduce)(function (tree, migration) {
      return migration(tree);
    }, collection, (0, _mapWithIndex2.default)(function (unction, index) {
      return (0, _nestedApply2.default)((0, _ramda.unary)(_ramda.map))(unction)(index);
    }, folders));
  };
} // > ?  (Array of Functions):a -> (Array or Object):b -> Object:c
//
// This takes a list of functions (the folders) and an array of objects or an
// object of objects (the collection) to create a tree. Each function in
// the list of folders will in some way return a new object. All of the objects
// produced are then turned into a final tree.
//
// ``` javascript
// import {treeify} from "ramda-extra"
//
// const collection = [
//   {
//     id: "a1",
//     type: "resources",
//     attributes: {
//       version: "v1",
//       namespace: "accounts",
//     }
//   },
//   {
//     id: "a2",
//     type: "resources",
//     attributes: {
//       version: "v1",
//       namespace: "accounts",
//     }
//   },
//   {
//     id: "b1",
//     type: "resources",
//     attributes: {
//       version: "v1",
//       namespace: "profiles",
//     }
//   },
//   {
//     id: "b1",
//     type: "resources",
//     attributes: {
//       version: "v2",
//       namespace: "profiles",
//     }
//   }
// ]
//
// // The order goes from outer layer to deeper layer, so in this case the outer
// // level properties will be based on `prop("type")`, and the deepest layer
// // properties will be based on `prop("id")`.
// const functions = [
//   groupBy(prop("type")),
//   groupBy(path(["attributes", "namespace"])),
//   groupBy(path(["attributes", "version"])),
//   indexBy(prop("id")),
// ]
//
// treeify(functions)(collection)
// ```
//
// The resulting object looks like this:
//
// ``` javascript
// {
//   resources: {
//     accounts: {
//       v1: {
//         a1: {
//           id: "a1",
//           type: "resources",
//           attributes: {
//             version: "v1",
//             namespace: "accounts",
//           }
//         },
//         a2: {
//           id: "a2",
//           type: "resources",
//           attributes: {
//             version: "v1",
//             namespace: "accounts",
//           }
//         }
//       }
//     },
//     profiles: {
//       v1: {
//         b1: {
//           id: "b1",
//           type: "resources",
//           attributes: {
//             version: "v1",
//             namespace: "profiles",
//           }
//         }
//       },
//       v2: {
//         b1: {
//           id: "b1",
//           type: "resources",
//           attributes: {
//             version: "v2",
//             namespace: "profiles",
//           }
//         }
//       }
//     }
//   }
// }
// ```